# mypy-boto3-braket

[![PyPI - mypy-boto3-braket](https://img.shields.io/pypi/v/mypy-boto3-braket.svg?color=blue)](https://pypi.org/project/mypy-boto3-braket)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-braket.svg?color=blue)](https://pypi.org/project/mypy-boto3-braket)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Braket 1.17.3](https://boto3.amazonaws.com/v1/documentation/api/1.17.3/reference/services/braket.html#Braket) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.4.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-braket](#mypy-boto3-braket)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `Braket` service.

```bash
python -m pip install boto3-stubs[braket]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[braket]` in your environment: `python -m pip install 'boto3-stubs[braket]'`

Both type checking and auto-complete should work for `Braket` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[braket]` in your environment: `python -m pip install 'boto3-stubs[braket]'`

Both type checking and auto-complete should work for `Braket` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[braket]` in your environment: `python -m pip install 'boto3-stubs[braket]'`
- Run `mypy` as usual

Type checking should work for `Braket` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[braket]` in your environment: `python -m pip install 'boto3-stubs[braket]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Braket` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`BraketClient` provides annotations for `boto3.client("braket")`.

```python
import boto3

from mypy_boto3_braket import BraketClient

client: BraketClient = boto3.client("braket")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: BraketClient = session.client("braket")
```

### Paginators annotations

`mypy_boto3_braket.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_braket import BraketClient
from mypy_boto3_braket.paginator import (
    SearchDevicesPaginator,
    SearchQuantumTasksPaginator,
)

client: BraketClient = boto3.client("braket")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
search_devices_paginator: SearchDevicesPaginator = client.get_paginator("search_devices")
search_quantum_tasks_paginator: SearchQuantumTasksPaginator = client.get_paginator("search_quantum_tasks")
```







### Typed dictionations

`mypy_boto3_braket.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_braket.type_defs import (
    DeviceSummaryTypeDef,
    QuantumTaskSummaryTypeDef,
    CancelQuantumTaskResponseTypeDef,
    CreateQuantumTaskResponseTypeDef,
    GetDeviceResponseTypeDef,
    GetQuantumTaskResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    SearchDevicesFilterTypeDef,
    SearchDevicesResponseTypeDef,
    SearchQuantumTasksFilterTypeDef,
    SearchQuantumTasksResponseTypeDef,
)

def get_structure() -> DeviceSummaryTypeDef:
    return {
      ...
    }
```
